import numpy as np
import ujson


class JSONBinaryEncoder:
    block_size = 4

    def fill_block(self, data, fill=b'\00'):
        return data + fill * (self.block_size - len(data) % self.block_size)

    def encode_object(self, obj, keys=None, items=None, buffer=None, **params):
        keys = keys or []
        items = items or []
        buffer = buffer or bytes(self.block_size)

        if isinstance(obj, dict):
            obj = dict(obj)
            for k, v in obj.items():
                obj[k], items, buffer = self.encode_object(v, keys + [k], items, buffer, **params)

        if isinstance(obj, list):
            obj = list(obj)
            for k, v in enumerate(obj):
                obj[k], items, buffer = self.encode_object(v, keys + [k], items, buffer, **params)

        elif isinstance(obj, bytes):
            offset = len(buffer)
            items.append(dict(params, keys=keys, length=len(obj), offset=offset))
            buffer += self.fill_block(obj)
            obj = ''

        elif isinstance(obj, np.ndarray):
            obj, dtype, shape = obj.tobytes(), obj.dtype.name, obj.shape
            obj, items, buffer = self.encode_object(obj, keys, items, buffer, dtype=dtype, shape=shape)

        return obj, items, buffer

    def set_nested(self, obj: dict, keys: list, value):
        while len(keys) > 1:
            obj = obj[keys.pop(0)]
        obj[keys[0]] = value

    def dumps(self, obj: dict):
        obj, items, buffer = self.encode_object(obj)
        header = dict(obj)
        header['$items'] = items
        encoded_header = self.fill_block(ujson.dumps(header).encode('utf-8'), b' ')
        return encoded_header + buffer

    def loads(self, data: bytes):
        header_length = data.find(bytes(1))
        obj = ujson.loads(data[:header_length].decode('utf-8'))
        items = obj.pop('$items')
        data = data[header_length:]

        for item in items:
            value = data[item['offset']:item['offset'] + item['length']]
            if 'dtype' in item:
                value = np.frombuffer(value, dtype=item['dtype'])
            if 'shape' in item:
                value = value.reshape(item['shape'])
            self.set_nested(obj, item['keys'], value)

        return obj

    def write_file(self, file_path: str, obj: dict):
        with open(file_path, 'wb') as fp:
            fp.write(self.dumps(obj))

    def read_file(self, file_path: str) -> dict:
        with open(file_path, 'rb') as fp:
            return self.loads(fp.read())



import boto3
import base64
import math
from botocore.exceptions import ClientError
import datetime
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.asymmetric import padding
from botocore.signers import CloudFrontSigner
from pymongo import MongoClient
from urllib.parse import urlparse
import json
import os


_AWS_SESSION = None

def get_aws_session():
    global _AWS_SESSION
    if _AWS_SESSION is None:
        _AWS_SESSION = boto3.Session(profile_name='production-developer') # UPDATE: 02-19-2021, change to use prod-dev ased on last change in okta scripts. aws session (session is stored in  ~/.aws/credentials)
    return _AWS_SESSION

def rsa_signer(message):
    if (os.environ.get('CLOUDFRONT') and os.environ.get('CLOUDFRONT_KEY')):
        CLOUDFRONT = json.loads(get_secret(os.environ.get('CLOUDFRONT')))

        private_key = serialization.load_pem_private_key(base64.b64decode(CLOUDFRONT[os.environ.get('CLOUDFRONT_KEY')]), password=None, backend=default_backend())
        return private_key.sign(message, padding.PKCS1v15(), hashes.SHA1())
    else:
        pass

'''
    Attachments can be stored on different s3 buckets, we need to map them to the different cloudfront urls.
'''
def get_cloudfront_url(url):
    if (os.environ.get('CLOUDFRONT_URLS')):
        URLS = os.environ.get('CLOUDFRONT_URLS')
        urls = dict([ (u.split(':')[0], u.split(':')[1]) for u in URLS.split(',') ])
        url_data = urlparse(url)
        if urls[url_data.netloc.split('.')[0]]:
            cd_url = f"https://{urls[url_data.netloc.split('.')[0]]}{url_data.path}"
        else:
            cd_url = f"https://{url_data.netloc}{url_data.path}"

        return cd_url
    else:
        pass

'''
    Get public url

    Since we can not acces to s3 attachments url directly, we need to use the CloudFront alternative + sign those url to be able to access them
'''
def get_signed_url(url):
    if (os.environ.get('CLOUDFRONT') and os.environ.get('CLOUDFRONT_KEY')):
        CLOUDFRONT = json.loads(get_secret(os.environ.get('CLOUDFRONT')))
        key_id = CLOUDFRONT[os.environ.get('CLOUDFRONT_ID')]
        expires = datetime.datetime.today() + datetime.timedelta(hours=10)

        cloudfront_signer = CloudFrontSigner(key_id, rsa_signer) # create CloudFront signer using the secrets

        cd_url = get_cloudfront_url(url)
        signed_url = cloudfront_signer.generate_presigned_url( cd_url, date_less_than=expires)
        return signed_url
    else:
        pass


def get_db_connection():
    if (os.environ.get('MONGODB_URI') and os.environ.get('MONGODB_DB') and os.environ.get('MONGODB_CONNECTION')):
        MONGODB_URI = get_secret(os.environ.get('MONGODB_URI'))
        MONGODB_DB = os.environ.get('MONGODB_DB')
        uri = f"{json.loads(MONGODB_URI)['MONGODB_URI_READ_ONLY']}"
        client = MongoClient(uri)
        db = getattr(client, MONGODB_DB)
        return db
    else:
        pass

def get_db_3d_connection():
    if (os.environ.get('MONGODB_URI') and os.environ.get('MONGODB_DB') and os.environ.get('MONGODB_CONNECTION')):
        MONGODB_URI = get_secret(os.environ.get('MONGODB_URI'))
        MONGODB_DB = os.environ.get('MONGODB_DB')
        uri = f"{json.loads(MONGODB_URI)['MONGODB_URI_3D_READ_ONLY']}"
        client = MongoClient(uri)
        db = getattr(client, MONGODB_DB)
        return db
    else:
        pass

'''
    Get AWS data using AWS secret
'''
def get_secret(secret_name):
    region_name = "us-west-2"
    # Create a Secrets Manager client
    session = get_aws_session()
    client = session.client(
        service_name='secretsmanager',
        region_name=region_name
    )

    # In this sample we only handle the specific exceptions for the 'GetSecretValue' API.
    # See https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_GetSecretValue.html
    # We rethrow the exception by default.
    try:
        get_secret_value_response = client.get_secret_value(
            SecretId=secret_name
        )
    except ClientError as e:
        if e.response['Error']['Code'] == 'DecryptionFailureException':
            # Secrets Manager can't decrypt the protected secret text using the provided KMS key.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'InternalServiceErrorException':
            # An error occurred on the server side.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'InvalidParameterException':
            # You provided an invalid value for a parameter.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'InvalidRequestException':
            # You provided a parameter value that is not valid for the current state of the resource.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'ResourceNotFoundException':
            # We can't find the resource that you asked for.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
    else:
        # Decrypts secret using the associated KMS CMK.
        # Depending on whether the secret is a string or binary, one of these fields will be populated.
        if 'SecretString' in get_secret_value_response:
            secret = get_secret_value_response['SecretString']
        else:
            decoded_binary_secret = base64.b64decode(get_secret_value_response['SecretBinary'])
        return secret



import numpy as np
from .viewer import Viewer

def open_new_viewer(points, aggregated_frames):
    viewer = Viewer(points, aggregated_frames)
    return viewer

def open_viewer(points, point_size=0.005):
    import pptk
    v = pptk.viewer(points[:, :3], points[:, 3])
    v.set(
        point_size=point_size,
        floor_level=0.0,
        phi=np.pi,
        theta=np.pi / 2,
        lookat=[0, 0, 0],
        r=50
    )
    # v.wait()
    return v


def load_points(viewer, points, point_size=0.005):
    viewer.load(points[:, :3], points[:, 3])
    viewer.set(
        point_size=point_size,
        floor_level=0.0,
        phi=np.pi,
        theta=np.pi / 2,
        lookat=[0, 0, 0],
        r=50
    )
    return viewer



import numpy as np
import cv2
from multiprocessing.pool import ThreadPool
from JSONBinaryEncoder import JSONBinaryEncoder
import os
from glob import glob

encoder = JSONBinaryEncoder()
WORKERS = 4
FPS = 10


def format_point(p):
    return dict(zip(("x", "y", "z"), p))


def format_quaternion(q):
    return dict(zip(["w", "x", "y", "z"], q))


def get_points(scene, path):
    points = []
    intensities = []
    frame_offset = 0
    frame_offsets = []
    for frame_idx in range(0, len( scene.frames )):
        scene.get_frame(frame_idx).get_world_points()

        world_points = scene.get_frame(frame_idx).get_world_points()
        frame_points = np.float32(world_points[:, :3])
        point_intensities = np.float32(world_points[:, 3:4])
        assert len(frame_points) == len(point_intensities)
        print(f'Found {len(frame_points)} points for frame {frame_idx}')
        points.append(frame_points)
        intensities.append(point_intensities)
        frame_offsets.append(frame_offset)
        frame_offset += len(frame_points)

    encoder.write_file(f"{path}/scene_points.bs4", {
        'version': '4.0',
        'sensors': [{
            'type': 'lidar',
            'points': {
                'positions': np.concatenate(points),
                'intensities': np.concatenate(intensities),
            },
            'frame_offsets': frame_offsets
        }]
    })


def process_video(output, frames, camera):
    print(f'Processing camera {camera.id}...')
    files = []
    width = frames[0].images[camera.id].get_image().width
    height = frames[0].images[camera.id].get_image().height
    for frame in frames:
        files.append(frame.images[camera.id].image_path)

    video_file = f'{output}/video_{camera.id}.mp4'
    fourcc = cv2.VideoWriter_fourcc(*'avc1')

    size = (width, height)

    out = cv2.VideoWriter(video_file, fourcc, FPS, size)

    for image_file in files:
        frame = cv2.imread(image_file)
        frame = cv2.resize(frame, size)
        out.write(frame)

    out.release()

    return video_file


def process_camera(scene, camera_name, path):
    camera_poses = []
    camera = scene.get_camera(camera_name)

    image_width = scene.frames[0].images[camera.id].get_image().width
    image_height = scene.frames[0].images[camera.id].get_image().height

    for frame_idx, frame in enumerate(scene.frames):
        if camera.world_poses:
            wct = camera.world_poses[frame.id]
        else:
            wct = frame.transform @ camera.pose

        camera_poses.append({
            'position': format_point(wct.position),
            'heading': format_quaternion(wct.quaternion)
        })

    video_file = process_video(path, scene.frames, camera)

    D = camera.D

    distortion = dict(
        model=camera.model,
        skew=camera.skew,
        k1=float(D[0]),
        k2=float(D[1]),
        p1=float(D[2]),
        p2=float(D[3]),
        k3=float(D[4]),
        k4=float(D[5]),
        k5=float(D[6]) if len(D) >= 7 else 0,
        k6=float(D[7]) if len(D) >= 8 else 0,
        scale_factor=camera.scale_factor,
    )
    cam_sensor = dict(
        type='camera',
        name=camera_name,
        fps=FPS,
        imageSize=dict(
            width=image_width,
            height=image_height
        ),
        poses=camera_poses,
        video=np.frombuffer(open(video_file, 'rb').read(), dtype=np.uint8),
        distortion=distortion,
        fx=int(camera.fx),
        fy=int(camera.fy),
        cx=int(camera.cx),
        cy=int(camera.cy)
    )

    return cam_sensor


def get_cameras(scene, path, camera_name="all"):
    if camera_name == "all":
        pool = ThreadPool(WORKERS)
        pool_input = [(scene, camera.id, path) for camera in scene.cameras]
        camera_sensors = pool.starmap(process_camera, pool_input)
    else:
        camera_sensors = [process_camera(scene, camera_name, path)]

    encoder.write_file(f'{ path }/scene_camera_{camera_name}.bs4', {
        'version': '4.0',
        'sensors': camera_sensors,
    })

    video_files = glob(f'{ path }/video_*.mp4')
    for video in video_files:
        os.remove(video)


def combine_scenes(camera_name, path, filename):
    cameras_scene = encoder.read_file(f'{ path }/scene_camera_{camera_name}.bs4')
    os.remove(f'{ path }/scene_camera_{camera_name}.bs4')

    points_scene = encoder.read_file(f"{ path }/scene_points.bs4")
    os.remove(f"{ path }/scene_points.bs4")

    out_file = f'{ path }/{filename}.bs4'
    encoder.write_file(out_file, {
        'version': '4.0',
        'sensors': cameras_scene['sensors'] + points_scene['sensors']
    })



import numpy as np
import open3d as o3d
import matplotlib.cm as cm
from pyquaternion import Quaternion

class Viewer():
    def __init__(self, points, aggregated_frames):
        self.current_frame = 0
        self.aggregated_frames = int(aggregated_frames/2)
        self.aggregated_mode = False
        self.pcs = [] # list point clouds (one pc per frame)
        colors = cm.rainbow(np.linspace(0, 1, len(points))) # define a rainbow secuence of colors for each frame

        # create pointcloud per frame
        for index in range(0, len(points)):
            #  print(len(points[index]))
            pc = o3d.geometry.PointCloud()
            pc.points = o3d.utility.Vector3dVector(np.array(points[index][:,:3], dtype=np.float32))
            color = np.tile(np.array(colors[index][:3], dtype=np.float32),(len(points[index]),1))
            pc.colors = o3d.utility.Vector3dVector(color)
            self.pcs.append(pc)


        # Define new keybinding here (remember to add them to the help screen)
        self.print_help()
        vis = o3d.visualization.VisualizerWithKeyCallback()
        vis.register_key_callback(ord("P"), self.previous_frame)
        vis.register_key_callback(ord("N"), self.next_frame)
        vis.register_key_callback(ord("A"), self.aggregated_view)
        vis.register_key_callback(ord("T"), self.top_view)
        vis.register_key_callback(ord("S"), self.side_view)
        self.vis = vis
        self.vis.create_window()
        self.set_camera()
        self.vis.run()


    def set_camera(self):
        self.vis.add_geometry(self.pcs[self.current_frame])
        self.vis.add_geometry(o3d.geometry.TriangleMesh.create_sphere().paint_uniform_color(np.array([0,1,0]))) # add car as a green sphere at point [0,0,0]

        opt = self.vis.get_render_option()
        opt.background_color = np.asarray([0, 0, 0]) # background color = black
        opt.show_coordinate_frame = True # show cross with the axis
        opt.point_size = 3.0 # define point size (bigger than this make the scene looks weird)

    def top_view(self, vis):
        cam = self.vis.get_view_control().convert_to_pinhole_camera_parameters()
        pose = np.eye(4)
        pose[:3, :3] = Quaternion(array=np.array([0.0, -1.0, 0.0, 0.0])).rotation_matrix
        pose[:3, 3] = [0, 0, 10]
        cam.extrinsic = pose
        self.vis.get_view_control().convert_from_pinhole_camera_parameters(cam)

    def side_view(self, vis):
        cam = self.vis.get_view_control().convert_to_pinhole_camera_parameters()
        pose = np.eye(4)
        pose[:3, :3] = Quaternion(array=np.array([1.0, 1.0, 0.0, 0.0])).rotation_matrix
        pose[:3, 3] = [0, 0, 10]
        cam.extrinsic = pose
        self.vis.get_view_control().convert_from_pinhole_camera_parameters(cam)


    def next_frame(self, vis):
        if len(self.pcs) > self.current_frame + 1 and not self.aggregated_mode:
            self.current_frame+=1
            self.vis.clear_geometries()
            self.vis.add_geometry(self.pcs[self.current_frame])
            self.set_camera()
            print(f"You are now at frame {self.current_frame}")

    def previous_frame(self, vis):
        if (self.current_frame > 0) and not self.aggregated_mode:
            self.current_frame-=1
            self.vis.clear_geometries()
            self.vis.add_geometry(self.pcs[self.current_frame])
            self.set_camera()
            print(f"You are now at frame {self.current_frame}")

    def aggregated_view(self, vis):
        if self.aggregated_mode: # go out of aggregated mode
            print("aggregated mode - OFF")
            self.vis.clear_geometries()
            self.vis.add_geometry(self.pcs[self.current_frame], True)
            self.aggregated_mode = False
        else: #set aggregated mode on
            print("aggregated mode - ON")
            # display current_frame +/- self.aggregated_frames (default 5) frames if possible
            min_frame = self.current_frame - self.aggregated_frames if self.current_frame - self.aggregated_frames > 0 else 0
            max_frame = self.current_frame + self.aggregated_frames if self.current_frame + self.aggregated_frames < len(self.pcs) else len(self.pcs)
            print(f"Frames {min_frame} to {max_frame}")
            for index in range(min_frame, max_frame):
                self.vis.add_geometry(self.pcs[index], True)
                self.aggregated_mode = True
        self.set_camera()

    def print_help(self):
        print("""
                -- Frame control --
      N : Next frame
      P : Previous frame
      A : Aggregated view (default 10 frames, -/+5 frames from the current frame)
      T : Top view
      S : Side View
      H : Help (more options)

                -- Mouse view control --
      Left button + drag         : Rotate.
      Ctrl + left button + drag  : Translate.
      Wheel button + drag        : Translate.
      Shift + left button + drag : Roll.
      Wheel                      : Zoom in/out.

    -- Keyboard view control --
      [/]          : Increase/decrease field of view.
      R            : Reset view point.
      Ctrl/Cmd + C : Copy current view status into the clipboard.
      Ctrl/Cmd + V : Paste view status from clipboard.

    -- General control --
      Q, Esc       : Exit window.
      H            : Print help message.
      PrtScn       : Take a screen capture.
      D            : Take a depth capture.
      O            : Take a capture of current rendering settings.
                """)



import numpy as np
import json
import os
from scale_lidar_io import LidarScene, Transform
from .view_utils import open_viewer, open_new_viewer
from .awsHandler import get_secret, get_db_connection, get_signed_url
from bson.objectid import ObjectId
from pyquaternion import Quaternion
import base64
import requests
from .lidarLiteHelper import get_points, get_cameras, combine_scenes

class DebugLidarScene(LidarScene):
    '''
        New Viewer method using open3d, this will work with python 3.8
    '''
    def preview(self, frame_id=None, file=None, aggregated_frames=10):
        if file:
            np.save(file, self.get_all_world_points())
        else:
            return open_new_viewer(self.get_all_world_points(), aggregated_frames)

    def get_all_world_points(self):
        all_points = []
        for idx, frame in enumerate(self.frames):
            points = frame.get_world_points()
            points[:, 3] = idx
            all_points.append(points)
        return all_points

    '''
        This method use PPTK, old Viewer implementation, leaving it here as a fallback
        I'm seing issue with the new viewer on pointclopuds with +150k points, need more testing but just in case I leave this as an alternative
        I've tested this method with 400k pointscloud and it worked fine
        this method will run only on python 3.6.0 (pptk requirement)
    '''
    def preview_motion(self, file=None):
        if file:
            np.save(file, self.get_all_world_points())
        else:
            return open_viewer(np.vstack(self.get_all_world_points()), point_size=0.005)

    '''
        Method to load the task attachments and add the data to the scene
    '''
    def load_task_attachments(self, task_id, attachments, load_images):
        cached = False   # Flag used to create the cache data if necessary.

        if os.path.exists(".cache"): # check for cache folder
            if os.path.exists(os.path.join(".cache", f"{task_id}")): # check for cache folder for this task
                cached = True
            else:
                os.makedirs(os.path.join(".cache", f"{task_id}")) # create a folder per each task
        else:
            os.makedirs(f".cache/{task_id}") # create a folder per each task

        for index, attachment in enumerate(attachments):
            # store in local cache folder if necessary
            if not cached:
                print(f"Loading attachment {index}")
                signed_url = get_signed_url(attachment)
                r = requests.get(signed_url)
                attachment_data = r.json()
                # Load point
                points = np.frombuffer(base64.b64decode(attachment_data['points']), 'float32').reshape([-1, 3])
                intensity = np.frombuffer(base64.b64decode(attachment_data['intensities']), 'float32').reshape([-1, 1])
                points = np.hstack((points,intensity))  # add intensity to the points
                np.save(os.path.join(".cache", f"{task_id}", f"frame-{index}.npy"), points) # save points into file
                del attachment_data['points']   # delete base64 points to store only the calibration data
                del attachment_data['intensities']

                with open(os.path.join(".cache", f"{task_id}", f"calibration-{index}.json"), 'w') as outfile:   # save calibration file
                    json.dump(attachment_data, outfile)

                if load_images: # maybe working on local we don't want to load the images to work faster
                    for camera_index, image in enumerate(attachment_data['images']):
                        print(f"Loading image {camera_index} of {len(attachment_data['images'])}")
                        signed_image = get_signed_url(image['image_url'])
                        r = requests.get(signed_image, stream=True)
                        if r.status_code == 200:
                            with open(os.path.join(".cache", f"{task_id}", f"camera-{camera_index}-{index}.jpg"), 'wb') as f:   # Save camera images
                                for chunk in r:
                                    f.write(chunk)

            # load points and device calibration values
            with open(os.path.join(".cache", f"{task_id}", f"calibration-{index}.json")) as json_file:
                calibration_data = json.load(json_file)
                device_position = list(calibration_data['device_position'].values()) if 'device_position' in calibration_data else list(calibration_data['devicePosition'].values())
                device_transformation = Transform.from_Rt(
                    Quaternion(np.array(list(calibration_data['device_heading'].values())) if 'device_heading' in calibration_data  else [1,0,0,0]),
                    np.array(device_position)
                )
                # load device data
                self.get_frame(index).apply_transform(device_transformation) # add frame transformation
                # load points
                self.get_frame(index).add_points(np.load(os.path.join(".cache", f"{task_id}", f"frame-{index}.npy")), transform=device_transformation.inverse) # need to remove the frame transformation
                if load_images: # maybe working on local we don't want to load the images to work faster
                    if index == 0:  # we calibate the cameras just one time (first frame)
                        with open(os.path.join(".cache", f"{task_id}", f"calibration-{index}.json")) as json_file:
                            calibration_data = json.load(json_file)
                            for camera_index, image in enumerate(calibration_data['images']):
                                distortion = [value for value in [image[key] if key in image.keys() else 0 for key in ['k1', 'k2', 'p1', 'p2', 'k3', 'k4']] ] # sometime we don't have all the cohefficients
                                position = list(image['position'].values())
                                self.get_camera(camera_index).calibrate(
                                        pose= Transform().from_Rt(
                                            Quaternion(image['heading']['w'], image['heading']['x'], image['heading']['y'], image['heading']['z']).rotation_matrix,
                                            np.array([position[0], position[1], position[2]])
                                            ),
                                        K=np.array([ [image['fx'],0,image['cx']],
                                            [0, image['fy'],image['cy']],
                                            [0,0,1]]),
                                        D=distortion,
                                        scale_factor=image['scale_factor'] if 'scale_factor' in image else 1,
                                        skew=image['skew'] if 'skew' in image else 0,
                                        model=image['camera_model'] if 'camera_model' in image else 'brown_conrady')
                                self.get_camera(camera_index).apply_transform(device_transformation.inverse) # need to remove the frame transformation
                    # load camera images
                    for camera_index, image in enumerate(calibration_data['images']):
                        self.get_frame(index).get_image(camera_index).load_file(os.path.join(".cache", f"{task_id}", f"camera-{camera_index}-{index}.jpg"))

    '''
        Method to load a task from a task ID
    '''
    def load_from_task(self, task_id=None, frames=0, load_images=True):
        if task_id:
            print("Connecting to DB")
            self.db = get_db_connection()
            subtasks = self.db['subtasks']
            results = subtasks.find({'task': ObjectId(task_id)})
            for r in results:
                attachments = r['params']['attachments'][:frames] if frames > 0 else r['params']['attachments'] # limit number of loaded frames
                print(f"Loading {len(attachments)} frames")
                self.load_task_attachments(task_id, attachments, load_images)
            return self


    def to_bs4(self, path, filename, camera="all"):
        get_points(self, path)
        get_cameras(self, path, camera)

        combine_scenes(camera, path, filename)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="scale_lidar_io_debug",
    version="0.1.51",
    author="Scale AI",
    author_email="rodrigo.belfiore@scale.com, ivan.roumec@scale.com",
    description="Lidar data conversion helpers",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['scale_lidar_io_debug'],
    install_requires=[
        'scale-lidar-io',
        'scaleapi>=2.0.3',
        'pytest',
        'pymongo',
        'open3d',
        'cryptography',
        'requests',
        'awscli',
        'smart_open',
        'boto3',
        'dataclasses',
        'laspy',
        'matplotlib',
        'numpy',
        'opencv-python',
        'open3d',
        'pandas',
        'Pillow',
        'PyYAML',
        'transforms3d',
        'ujson',
        'pyquaternion',
        'pyntcloud',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
